# encoding: UTF-8
=begin
(c) TIG 2023
###
All rights reserved.
THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES; 
INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND 
FITNESS FOR A PARTICULAR PURPOSE.
###
ContainerNameMaterialCode.rb
Set up by ContainerNameMaterial.rb.
Set up menu item under Plugins|Extensions
When it's run it processes all selected containers [groups & instances] and their nested containers.
If the container has a material it's renamed to match.
Otherwise it's left unchanged.
=end
module TIG
  module ContainerNameMaterial
    ### menu setup
    unless @loaded
      MENU = UI.menu("Plugins")
      CMD = UI::Command.new(NAME){self.new()}
      CMD.tooltip = "#{NAME} #{DESC}"
      CMD.status_bar_text = "#{NAME}"
      MENU.add_item(CMD)
      @loaded = true
    end
    ### main code
    def self.new()
      @model = Sketchup.active_model
      @ss = @model.selection
      @groups = @ss.grep(Sketchup::Group)
      @insts  = @ss.grep(Sketchup::ComponentInstance)
      @gcount  = 0
      @gcountX = 0
      @icount  = 0
      @icountX = 0
      @model.start_operation(NAME, true)
      @groups.each{|gp| self.do_group(gp) }
      @insts.each{|it| self.do_inst(it) }
      UI.messagebox("#{NAME}:\n\nRenamed #{@gcount} Groups\nRenamed #{@icount} Instances\n#{@gcountX} Groups left unnamed\n#{@icountX} Instances left unnamed\n
      Nested Containers without materials will display there parent's material, but are unnamed...")
      @model.commit_operation
    end
    def self.do_group(gp)
      if m=gp.material
        gp.name = m.display_name
        @gcount += 1
      else #no mat
        @gcountX += 1
      end
      gps = gp.entities.grep(Sketchup::Group)
      gps.each{|g| self.do_group(g) }
      ins = gp.entities.grep(Sketchup::ComponentInstance)
      ins.each{|i| self.do_inst(i) }
    end
    def self.do_inst(i)
      if m=i.material
        i.name = m.display_name
        @icount += 1
      else #no mat
        @icountX += 1
      end
      gps = i.definition.entities.grep(Sketchup::Group)
      gps.each{|g| self.do_group(g) }
      ins = i.definition.entities.grep(Sketchup::ComponentInstance)
      ins.each{|i| self.do_inst(i) }
    end
    
  end#module
end#module
